@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/04/21] if 判定内に&があるためのエラー修正
  -      [2006/08/29] ファイルパスの定数名を変更
  -      [2006/08/28] コメント一覧に投稿者画像追加
  -      [2006/08/27] 基礎情報を親クラスから引っ張るように修正
@@ -87,7 +88,8 @@ class webapp extends WAP_friend
 
         $this->set_topic();
         /* 閲覧権限があるか？ */
-        if (empty($this->visibility & $this->topic['visibility'])){
+        $visibility = $this->visibility & $this->topic['visibility'];
+        if (empty($visibility)){
             header('Location: '.HTTP_ACTION.'friend/forum/list/'.$this->ref_friend.'/');
             exit();
         }
