@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/04/21] if 判定内に&があるためのエラー修正
  -      [2006/08/28] 基礎情報を親クラスから引っ張るように修正
  -      [2006/07/10] 作成
  - ======================================================================== */
@@ -81,7 +82,8 @@ class webapp extends WAP_friend
         
         $this->set_topic();
         /* 閲覧権限があるか？ */
-        if (empty($this->visibility & $this->topic['visibility'])){
+        $visibility = $this->visibility & $this->topic['visibility'];
+        if (empty($visibility)){
             header('Location: '.HTTP_ACTION.'friend/forum/list/'.$this->ref_friend.'/');
             exit();
         }
