@@ -2,7 +2,7 @@
 /* ========================================================================
  - [modules/private/diary/wysiwyg.php]
  -      日記記事投稿
- -      Copyright (c) 2006 Yujiro Takahashi
+ -      Copyright (c) 2006-2007 Yujiro Takahashi
  - ライセンス:
  -      This program is free software; you can redistribute it and/or
  -      modify it under the terms of the GNU General Public License
@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/03/11] 本文の入力データのエスケープ処理を変更
  -      [2007/02/02] 本文の初期値、改行部分を修正
  -      [2007/02/02] カテゴリ選択更新時エラーを修正
  -      [2006/09/25] sns_dia_entry.link を更新しないように変更
@@ -242,11 +243,11 @@ class webapp extends WAP_private
      */
     function format_body($string)
     {
-        $string = str_ireplace('<p>', '', $string);
-        $string = str_ireplace('</p>', '<br />', $string);
+        $string = preg_replace('/<p>/i', '', $string);
+        $string = preg_replace('/<\/p>/i', '<br />', $string);
 
-        $string = str_ireplace('<div>', '', $string);
-        $string = str_ireplace('</div>', '<br />', $string);
+        $string = preg_replace('/<div>/i', '', $string);
+        $string = preg_replace('/<\/div>/i', '<br />', $string);
 
         return $string;
     }
@@ -290,7 +291,7 @@ class webapp extends WAP_private
      */
     function do_query()
     {
-        // 新規登録以外の処理
+        /* 新規登録以外の処理 */
         if (!empty($this->id)){
             $this->objmnp->setCurID($this->id);
             $this->init_effect();
@@ -299,7 +300,7 @@ class webapp extends WAP_private
             $this->objmnp->setValue('regist_date', date('Y-m-d H:i:s'));
         }
 
-        // 直接入力
+        /* 直接入力 */
         $this->objmnp->setValue('modify', date('Y-m-d H:i:s'));
         $this->objmnp->setValue('ref_diary', $this->ref_diary);
         $this->objmnp->setValue('visibility', VISIBILITY_PROTECTED);
@@ -309,13 +310,24 @@ class webapp extends WAP_private
         $func = array('webapp', 'format_body');
         $this->objmnp->setInputEffect('body', array('func'=>$func, 'key'=>'body'));
 
-        // 更新しない項目名
+        /* 更新しない項目名 */
         $skip = array(
             'ref_account',
             'regist_date',
             'link',
+            'body',
         );
-        return $this->objmnp->execute($this,$skip);
+
+        /* 入力条件を指定 */
+        $validates = array(
+            'body'=> array(
+                'type'=>    'string',
+                'option'=>  null,
+                'required'=>true,
+                'effect'=>  array('RKT_validate', 'strip_slashes'),
+            ),
+        );
+        return $this->objmnp->execute($this,$skip,$validates);
     }
 
     /**
