@@ -20,6 +20,7 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--      [2007/04/21] 問合せ内容を修正、問合せ対応を追加
 --      [2007/02/02] 日記の未読コメントflagを追加
 --      [2007/01/30] メッセージの添付画像(sns_fri_picture)を追加
 --      [2007/01/21] お友達のお友達名簿を修正
@@ -928,15 +929,30 @@ CREATE TABLE `sns_inq_inquire` (
   `ref_category` int(11),
   `ref_account` int(11),
   `status` int(11) NOT NULL,
+  `flag` int(11) default '0',
   `name` varchar(128) NOT NULL,
   `url` varchar(128),
   `email` blob,
   `comment` text NOT NULL,
+  PRIMARY KEY  (`id`)
+) TYPE=MyISAM AUTO_INCREMENT=1;
+
+-- 
+-- 問合せ対応
+-- 
+CREATE TABLE `sns_inq_response` (
+  `id` int(11) unsigned NOT NULL auto_increment,
+  `modify` timestamp NOT NULL,
+  `regist_date` timestamp NOT NULL,
+  `ref_inquire` int(11),
+  `ref_account` int(11) NOT NULL,
+  `send` int(11),
   `subject` varchar(255) NOT NULL,
   `body` text NOT NULL,
   PRIMARY KEY  (`id`)
 ) TYPE=MyISAM AUTO_INCREMENT=1;
 
+
 -- --------------------------------------------------------
 -- 
 -- システムからの記事　カテゴリマスター情報
